pymadx Documentation
====================

pymadx is a set of classes and functions to load MADX output as well as prepare
MADX models. The package overall functions as a holder for any code required to
load and manipulate MADX output data as well as prepare MADX and PTC models
programmatically.

.. toctree::
   :maxdepth: 2

   licence
   authorship
   installation
   tfsloading
   plotting
   building
   converting
   moduledocs
   version_history
   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
